.. generic convenience modules


Generic Convenience Modules
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pynbody.bridge
   :members:

.. automodule:: pynbody.filt
   :members:

.. automodule:: pynbody.halo
   :members:

.. automodule:: pynbody.sph
   :members:
